@@ -309,7 +309,7 @@ class ParserTests(unittest.TestCase):
         'first_name': 'Test',
         'gateway_token': None,
         'id': '10681b62-6dcd-102e-b098-40402145ee8b',
-        'is_vat_excempt': None,
+        'is_vat_exempt': '0',
         'last_name': 'User',
         'meta_data': [   {   'created_datetime': datetime(2011, 1, 10, 5, 45, 51, tzinfo=tzutc()),
                              'id': '106953e2-6dcd-102e-b098-40402145ee8b',
@@ -404,7 +404,7 @@ class ParserTests(unittest.TestCase):
         'first_name': 'Test',
         'gateway_token': None,
         'id': 'a1f143e0-6e65-102e-b098-40402145ee8b',
-        'is_vat_excempt': None,
+        'is_vat_exempt': '0',
         'last_name': 'User',
         'meta_data': [],
         'modified_datetime': datetime(2011, 1, 10, 23, 57, 58, tzinfo=tzutc()),
@@ -531,7 +531,7 @@ class ParserTests(unittest.TestCase):
         'first_name': 'Test',
         'gateway_token': None,
         'id': '95d7696a-7fda-11e0-a51b-40403c39f8d9',
-        'is_vat_excempt': None,
+        'is_vat_exempt': '0',
         'last_name': 'User',
         'meta_data': [],
         'modified_datetime': datetime(2011, 5, 16, 16, 36, 1, tzinfo=tzutc()),
@@ -625,4 +625,4 @@ class ParserTests(unittest.TestCase):
         pp = pprint.PrettyPrinter(indent=4)
         pp.pprint(result)
         self.assertEquals(expected, result)
-        
\ No newline at end of file
+        
