@@ -151,12 +151,12 @@ class ProductTests(unittest.TestCase):
         self.get_customer(meta_data = {'key_1': 'value_1', 'key2': 'value_2'})
     
     @clear_users
-    def test_create_customer_with_true_vat_excempt(self):
-        self.get_customer(is_vat_excempt=True)
+    def test_create_customer_with_true_vat_exempt(self):
+        self.get_customer(is_vat_exempt=True)
     
     @clear_users
-    def test_create_customer_with_false_vat_excempt(self):
-        self.get_customer(is_vat_excempt=False)
+    def test_create_customer_with_false_vat_exempt(self):
+        self.get_customer(is_vat_exempt=False)
         
     @clear_users
     def test_create_customer_with_vat_number(self):
@@ -252,7 +252,6 @@ class ProductTests(unittest.TestCase):
 
     @clear_users
     def test_update_paypal_customer(self):
-        raise SkipTest('Skipping this test until a bug in CG is fixed.')
         data = copy(self.paypal_defaults)
         customer = self.get_customer(**data)
         customer.update(
@@ -260,8 +259,6 @@ class ProductTests(unittest.TestCase):
             return_url='http://example.com/update-success/',
             cancel_url='http://example.com/update-cancel/',
         )
-        print customer.subscription.redirect_url
-        assert False
 
         
     @clear_users
